@@ -12,9 +12,8 @@ from warnings import warn
 from attrs import define, field
 
 from kedro.config import AbstractConfigLoader, MissingConfigException
-from kedro.framework.project import settings
-from kedro.io import CatalogProtocol, DataCatalog  # noqa: TCH001
-from kedro.io.warning_utils import suppress_catalog_warning
+from kedro.framework.context import CatalogCommandsMixin
+from kedro.io import CatalogProtocol, DataCatalog
 from kedro.pipeline.transcoding import _transcode_split
 
 if TYPE_CHECKING:
@@ -25,19 +24,20 @@ def _is_relative_path(path_string: str) -> bool:
     """Checks whether a path string is a relative path.
 
     Example:
-    ::
-        >>> _is_relative_path("data/01_raw") == True
-        >>> _is_relative_path("info.log") == True
-        >>> _is_relative_path("/tmp/data/01_raw") == False
-        >>> _is_relative_path(r"C:\\info.log") == False
-        >>> _is_relative_path(r"\\'info.log") == False
-        >>> _is_relative_path("c:/info.log") == False
-        >>> _is_relative_path("s3://info.log") == False
+    ``` python
+    _is_relative_path("data/01_raw") == True
+    _is_relative_path("info.log") == True
+    _is_relative_path("/tmp/data/01_raw") == False
+    _is_relative_path(r"C:\\info.log") == False
+    _is_relative_path(r"\\'info.log") == False
+    _is_relative_path("c:/info.log") == False
+    _is_relative_path("s3://info.log") == False
 
     Args:
         path_string: The path string to check.
     Returns:
         Whether the string is a relative path.
+    ```
     """
     # os.path.splitdrive does not reliably work on non-Windows systems
     # breaking the coverage, using PureWindowsPath instead
@@ -66,19 +66,19 @@ def _convert_paths_to_absolute_posix(
     through `kedro run` or `__main__.py` entrypoints.
 
     Example:
-    ::
-        >>> conf = _convert_paths_to_absolute_posix(
-        >>>     project_path=Path("/path/to/my/project"),
-        >>>     conf_dictionary={
-        >>>         "handlers": {
-        >>>             "info_file_handler": {
-        >>>                 "filename": "info.log"
-        >>>             }
-        >>>         }
-        >>>     }
-        >>> )
-        >>> print(conf['handlers']['info_file_handler']['filename'])
-        "/path/to/my/project/info.log"
+    ```` python
+    conf = _convert_paths_to_absolute_posix(
+        project_path=Path("/path/to/my/project"),
+        conf_dictionary={
+            "handlers": {
+                "info_file_handler": {
+                    "filename": "info.log"
+                }
+            }
+        }
+    )
+    print(conf['handlers']['info_file_handler']['filename'])
+    "/path/to/my/project/info.log"
 
     Args:
         project_path: The root directory to prepend to relative path to make absolute path.
@@ -87,6 +87,7 @@ def _convert_paths_to_absolute_posix(
         A dictionary containing only absolute paths.
     Raises:
         ValueError: If the provided ``project_path`` is not an absolute path.
+    ```
     """
     if not project_path.is_absolute():
         raise ValueError(
@@ -136,7 +137,7 @@ def _validate_transcoded_datasets(catalog: CatalogProtocol) -> None:
             `_transcode_split` function.
 
     """
-    for dataset_name in catalog._datasets.keys():
+    for dataset_name in catalog:
         _transcode_split(dataset_name)
 
 
@@ -177,7 +178,7 @@ class KedroContext:
         package_name: Package name for the Kedro project the context is
             created for.
         hook_manager: The ``PluginManager`` to activate hooks, supplied by the session.
-        extra_params: Optional dictionary containing extra project parameters.
+        runtime_params: Optional dictionary containing runtime project parameters.
             If specified, will update (and therefore take precedence over)
             the parameters retrieved from the project configuration.
 
@@ -188,7 +189,7 @@ class KedroContext:
     env: str | None = field(init=True)
     _package_name: str = field(init=True)
     _hook_manager: PluginManager = field(init=True)
-    _extra_params: dict[str, Any] | None = field(
+    _runtime_params: dict[str, Any] | None = field(
         init=True, default=None, converter=deepcopy
     )
 
@@ -217,11 +218,12 @@ class KedroContext:
         except MissingConfigException as exc:
             warn(f"Parameters not found in your Kedro project config.\n{exc!s}")
             params = {}
-        _update_nested_dict(params, self._extra_params or {})
+        _update_nested_dict(params, self._runtime_params or {})
         return params  # type: ignore
 
     def _get_catalog(
         self,
+        catalog_class: type = DataCatalog,
         save_version: str | None = None,
         load_versions: dict[str, str] | None = None,
     ) -> CatalogProtocol:
@@ -242,55 +244,65 @@ class KedroContext:
         )
         conf_creds = self._get_config_credentials()
 
-        with suppress_catalog_warning():
-            catalog: DataCatalog = settings.DATA_CATALOG_CLASS.from_config(
-                catalog=conf_catalog,
-                credentials=conf_creds,
-                load_versions=load_versions,
-                save_version=save_version,
-            )
+        if catalog_class is DataCatalog:
+            catalog_class = compose_classes(catalog_class, CatalogCommandsMixin)
+
+        catalog: CatalogProtocol = catalog_class.from_config(  # type: ignore[attr-defined]
+            catalog=conf_catalog,
+            credentials=conf_creds,
+            load_versions=load_versions,
+            save_version=save_version,
+        )
+
+        parameters = self._get_parameters()
+
+        # Add parameters data to catalog.
+        for param_name, param_value in parameters.items():
+            catalog[param_name] = param_value
 
-        feed_dict = self._get_feed_dict()
-        catalog.add_feed_dict(feed_dict)
         _validate_transcoded_datasets(catalog)
+
         self._hook_manager.hook.after_catalog_created(
             catalog=catalog,
             conf_catalog=conf_catalog,
             conf_creds=conf_creds,
-            feed_dict=feed_dict,
+            parameters=parameters,
             save_version=save_version,
             load_versions=load_versions,
         )
         return catalog
 
-    def _get_feed_dict(self) -> dict[str, Any]:
-        """Get parameters and return the feed dictionary."""
+    def _get_parameters(self) -> dict[str, Any]:
+        """Returns a dictionary with data to be added in memory as `MemoryDataset`` instances.
+        Keys represent parameter names and the values are parameter values."""
         params = self.params
-        feed_dict = {"parameters": params}
+        params_dict = {"parameters": params}
 
-        def _add_param_to_feed_dict(param_name: str, param_value: Any) -> None:
-            """This recursively adds parameter paths to the `feed_dict`,
+        def _add_param_to_params_dict(param_name: str, param_value: Any) -> None:
+            """This recursively adds parameter paths that are defined in `parameters.yml`
+            with the addition of any extra parameters passed at initialization to the `params_dict`,
             whenever `param_value` is a dictionary itself, so that users can
             specify specific nested parameters in their node inputs.
 
             Example:
-
-                >>> param_name = "a"
-                >>> param_value = {"b": 1}
-                >>> _add_param_to_feed_dict(param_name, param_value)
-                >>> assert feed_dict["params:a"] == {"b": 1}
-                >>> assert feed_dict["params:a.b"] == 1
+            ``` python
+            param_name = "a"
+            param_value = {"b": 1}
+            _add_param_to_params_dict(param_name, param_value)
+            assert params_dict["params:a"] == {"b": 1}
+            assert params_dict["params:a.b"] == 1
+            ```
             """
             key = f"params:{param_name}"
-            feed_dict[key] = param_value
+            params_dict[key] = param_value
             if isinstance(param_value, dict):
                 for key, val in param_value.items():
-                    _add_param_to_feed_dict(f"{param_name}.{key}", val)
+                    _add_param_to_params_dict(f"{param_name}.{key}", val)
 
         for param_name, param_value in params.items():
-            _add_param_to_feed_dict(param_name, param_value)
+            _add_param_to_params_dict(param_name, param_value)
 
-        return feed_dict
+        return params_dict
 
     def _get_config_credentials(self) -> dict[str, Any]:
         """Getter for credentials specified in credentials directory."""
@@ -306,3 +318,10 @@ class KedroContext:
 
 class KedroContextError(Exception):
     """Error occurred when loading project and running context pipeline."""
+
+
+def compose_classes(base: type, *mixins: type) -> type:
+    """Injecting mixins dynamically"""
+    t = (base, *mixins)
+    name = f"{base.__name__}With{''.join(x.__name__ for x in mixins)}"
+    return type(name, t, {})
