@@ -111,7 +111,7 @@ def _is_databricks() -> bool:
     return "DATABRICKS_RUNTIME_VERSION" in os.environ
 
 
-def _is_project(project_path: Union[str, Path]) -> bool:
+def is_kedro_project(project_path: Union[str, Path]) -> bool:
     """Evaluate if a given path is a root directory of a Kedro project or not.
 
     Args:
@@ -130,7 +130,7 @@ def _is_project(project_path: Union[str, Path]) -> bool:
         return False
 
 
-def _find_kedro_project(current_dir: Path) -> Any:  # pragma: no cover
+def find_kedro_project(current_dir: Path) -> Any:  # pragma: no cover
     """Given a path, find a Kedro project associated with it.
 
     Can be:
@@ -144,7 +144,7 @@ def _find_kedro_project(current_dir: Path) -> Any:  # pragma: no cover
     """
     paths_to_check = [current_dir, *list(current_dir.parents)]
     for parent_dir in paths_to_check:
-        if _is_project(parent_dir):
+        if is_kedro_project(parent_dir):
             return parent_dir
     return None
 
