@@ -24,6 +24,13 @@ base_catalog.update({
     }
 })
 
+runtime_patterns = {
+    "{placeholder}": {
+        "type": "pandas.CSVDataset",
+        "filepath": "{placeholder}.csv",
+    }
+}
+
 class TimeDataCatalog:
     def setup(self):
         self.catalog = DataCatalog.from_config(base_catalog)
@@ -32,7 +39,7 @@ class TimeDataCatalog:
         self.datasets = {
             f"dataset_new_{i}": CSVDataset(filepath="data.csv") for i in range(1, 1001)
         }
-        self.feed_dict = {
+        self.parameters = {
             f"param_{i}": i for i in range(1, 1001)
         }
 
@@ -40,6 +47,49 @@ class TimeDataCatalog:
         """Benchmark the time to initialize the catalog"""
         DataCatalog.from_config(base_catalog)
 
+    def time_contains(self):
+        """Benchmark the time to check if a dataset exists"""
+        for i in range(1,1001):
+            f"dataset_{i}" in self.catalog
+
+    def time_getitem(self):
+        """Benchmark the time to get a dataset"""
+        for i in range(1,1001):
+            self.catalog[f"dataset_{i}"]
+
+
+    def time_get(self):
+        """Benchmark the time to get a dataset"""
+        for i in range(1,1001):
+            self.catalog.get(f"dataset_{i}")
+
+    def time_iter(self):
+        """Benchmark the time to iterate over the catalog"""
+        for dataset in self.catalog:
+            pass
+
+    def time_keys(self):
+        """Benchmark the time to get the keys of the catalog"""
+        self.catalog.keys()
+
+    def time_values(self):
+        """Benchmark the time to get the items of the catalog"""
+        self.catalog.values()
+
+    def time_items(self):
+        """Benchmark the time to get the items of the catalog"""
+        self.catalog.items()
+
+    def time_setitem(self):
+        """Benchmark the time to set a dataset"""
+        for i in range(1,1001):
+            self.catalog[f"dataset_new_{i}"] = CSVDataset(filepath="data.csv")
+
+    def time_setitem_raw(self):
+        """Benchmark the time to add a memory dataset"""
+        for i in range(1,1001):
+            self.catalog[f"param_{i}"] = self.parameters[f"param_{i}"]
+
     def time_save(self):
         """Benchmark the time to save datasets"""
         for i in range(1,1001):
@@ -60,27 +110,7 @@ class TimeDataCatalog:
         for i in range(1,1001):
             self.catalog.release(f"dataset_{i}")
 
-    def time_add_all(self):
-        """Benchmark the time to add all datasets"""
-        # Have to initialise a new DataCatalog to avoid failing with DatasetAlreadyExistsError
-        catalog = DataCatalog.from_config(base_catalog)
-        catalog.add_all(self.datasets)
-
-    def time_feed_dict(self):
-        """Benchmark the time to add feed dict"""
-        # Have to initialise a new DataCatalog to avoid failing with DatasetAlreadyExistsError
-        catalog = DataCatalog.from_config(base_catalog)
-        catalog.add_feed_dict(self.feed_dict)
-
-    def time_list(self):
-        """Benchmark the time to list all datasets"""
-        self.catalog.list()
-
-    def time_shallow_copy(self):
-        """Benchmark the time to shallow copy the catalog"""
-        self.catalog.shallow_copy()
-
     def time_resolve_factory(self):
         """Benchmark the time to resolve factory"""
         for i in range(1,1001):
-            self.catalog._get_dataset(f"dataset_factory_{i}")
+            self.catalog.get(f"dataset_factory_{i}")
